~~-think of a name~~\
~~-get github working~~\
~~-work out what functions are wanted and add them to their respective files~~\
~~-make an init file and make sure it works~~\
~~-get all that on github with a readme file and a setup.cfg etc~~\
~~-build wheel~~\
~~-create pypi account and get token~~\
~~-get twine~~\
~~-upload to testpypi~~\
~~-test it~~\
~~-upload to pypi~~